"use client";

import { useState } from "react";
import ProgramsHeader from "@/components/programs/ProgramsHeader";
import ProgramsList from "@/components/programs/ProgramsList";
import ProgramFilters from "@/components/programs/ProgramFilters";
import { useProgramSearch } from "@/hooks/useProgramSearch";

export default function ProgramsPage() {
  const [isFiltersOpen, setIsFiltersOpen] = useState(false);
  const { 
    programs,
    isLoading,
    error,
    hasNextPage,
    fetchNextPage
  } = useProgramSearch();

  return (
    <div className="min-h-screen bg-background">
      <ProgramsHeader 
        onToggleFilters={() => setIsFiltersOpen(!isFiltersOpen)} 
      />
      <main className="container mx-auto px-4 py-8">
        <div className="grid lg:grid-cols-4 gap-8">
          <ProgramFilters 
            className={`lg:block ${isFiltersOpen ? 'block' : 'hidden'}`}
          />
          <div className="lg:col-span-3">
            <ProgramsList
              programs={programs}
              isLoading={isLoading}
              error={error}
              hasNextPage={hasNextPage}
              onLoadMore={fetchNextPage}
            />
          </div>
        </div>
      </main>
    </div>
  );
}